@@ -25,10 +25,8 @@
 #include <klocalizedstring.h>
 #include <kmessagebox.h>
 #include <kconfiggroup.h>
-#include <QUrl>
 #include <kprocess.h>
 
-#include <QFileInfo>
 #include <QSharedPointer>
 #include <QImage>
 
@@ -44,8 +42,8 @@ class Q_DECL_HIDDEN KIdentityManagement::SignaturePrivate
 {
 public:
     SignaturePrivate(Signature *qq)
-        : enabled(false)
-        , type(Signature::Disabled)
+        : type(Signature::Disabled)
+        , enabled(false)
         , inlinedHtml(false)
         , q(qq)
     {
@@ -64,12 +62,12 @@ public:
 
     /// The directory where the images will be saved to.
     QString saveLocation;
-    bool enabled;
     QString path;
     QString text;
     Signature::Type type;
-    bool inlinedHtml;
-    Signature *q;
+    bool enabled = false;
+    bool inlinedHtml = false;
+    Signature *q = nullptr;
 };
 
 static bool isCursorAtEndOfLine(const QTextCursor &cursor)
@@ -408,7 +406,7 @@ QString Signature::withSeparator(bool *ok) const
 
     const bool htmlSig = (isInlinedHtml() && d->type == Inlined);
     QString newline = htmlSig ? QStringLiteral("<br>") : QStringLiteral("\n");
-    if (htmlSig && signature.startsWith(QStringLiteral("<p"))) {
+    if (htmlSig && signature.startsWith(QLatin1String("<p"))) {
         newline.clear();
     }
 
